package com.composition.android.ad.gromore.load.request

import android.app.Activity
import android.content.Context
import com.bytedance.msdk.api.AdError
import com.bytedance.msdk.api.v2.ad.splash.GMSplashAd
import com.bytedance.msdk.api.v2.ad.splash.GMSplashAdLoadCallback
import com.bytedance.msdk.api.v2.slot.GMAdSlotSplash
import com.composition.android.ad.gromore.load.util.GMSettingConfig
import com.composition.android.ad.gromore.load.util.printAdFailInfo
import com.composition.android.ad.gromore.load.util.printAdInfo
import com.composition.android.lib.ad.basic.AdResult
import com.composition.android.lib.ad.bean.AdUnitBean
import com.composition.android.lib.ad.interfaces.IAdFormatRequest
import kotlinx.coroutines.suspendCancellableCoroutine
import kotlin.coroutines.resume

/**
 * @classname:
 * @author: LiuXiaoLong
 * @date: 2022/9/16
 * description:GroMore开屏广告加载类
 */
class GMAppOpenRequestImpl : IAdFormatRequest{
    override suspend fun load(context: Context, adUnitBean: AdUnitBean): AdResult {
        return suspendCancellableCoroutine {
            if (context is Activity){
                GMSettingConfig.loadAdConfig {
                    val mTTSplashAd = GMSplashAd(context, adUnitBean.adUnitId)
                    mTTSplashAd.loadAd(GMAdSlotSplash.Builder()
                        .build(),object : GMSplashAdLoadCallback{
                        override fun onSplashAdLoadFail(p0: AdError) {
                            printAdFailInfo(p0.code, p0.message)
                            if (it.isActive) {
                                it.resume(AdResult.Fail(adUnitBean, msg = "GroMore开屏广告加载失败:${p0.message}"))
                            }
                        }

                        override fun onSplashAdLoadSuccess() {
                            printAdInfo(adUnitBean)
                            if (it.isActive){
                                it.resume(AdResult.Success(adBean = adUnitBean, adObject = mTTSplashAd, msg = "GroMore开屏广告加载成功"))
                            }
                        }

                        override fun onAdLoadTimeout() {
                            printAdFailInfo(0, "GroMore开屏广告加载超时")
                            if (it.isActive){
                                it.resume(AdResult.Fail(adUnitBean, msg = "GroMore开屏广告加载超时"))
                            }

                        }
                    })
                }

            }else{
                if (it.isActive) {
                    it.resume(AdResult.Fail(adUnitBean, msg = "GroMore开屏广告需要context为Activity"))
                }
            }
        }
    }
}