package com.composition.android.ad.gromore.load.request

import android.app.Activity
import android.content.Context
import com.bytedance.msdk.api.AdError
import com.bytedance.msdk.api.v2.ad.interstitialFull.GMInterstitialFullAd
import com.bytedance.msdk.api.v2.ad.interstitialFull.GMInterstitialFullAdLoadCallback
import com.bytedance.msdk.api.v2.slot.GMAdOptionUtil
import com.bytedance.msdk.api.v2.slot.GMAdSlotInterstitialFull
import com.composition.android.ad.gromore.load.util.GMSettingConfig
import com.composition.android.ad.gromore.load.util.printAdFailInfo
import com.composition.android.ad.gromore.load.util.printAdInfo
import com.composition.android.lib.ad.basic.AdResult
import com.composition.android.lib.ad.bean.AdUnitBean
import com.composition.android.lib.ad.interfaces.IAdFormatRequest
import kotlinx.coroutines.suspendCancellableCoroutine
import kotlin.coroutines.resume

/**
 * @classname:
 * @author: LiuXiaoLong
 * @date: 2022/9/16
 * description:GroMore 插屏广告加载类
 */
class GMInterstitialRequestImpl : IAdFormatRequest {
    override suspend fun load(context: Context, adUnitBean: AdUnitBean): AdResult {
        return suspendCancellableCoroutine {
            GMSettingConfig.loadAdConfig {
                    if (context is Activity){
                        val mInterstitialFullAd = GMInterstitialFullAd(context, adUnitBean.adUnitId)
                        val adSlot = GMAdSlotInterstitialFull.Builder()
                            .setGMAdSlotBaiduOption(GMAdOptionUtil.getGMAdSlotBaiduOption().build())
                            .setGMAdSlotGDTOption(GMAdOptionUtil.getGMAdSlotGDTOption().build())
                            .build()

                        mInterstitialFullAd.loadAd(adSlot, object : GMInterstitialFullAdLoadCallback{
                            override fun onInterstitialFullLoadFail(p0: AdError) {
                                printAdFailInfo(p0.code, p0.message)
                                if (it.isActive){
                                    it.resume(AdResult.Fail(adUnitBean, msg = "GroMore插屏广告加载失败:${p0.message}"))
                                }
                            }

                            override fun onInterstitialFullAdLoad() {
                                //这里为广告加载成功，但还没缓存好
                            }

                            override fun onInterstitialFullCached() {
                                printAdInfo(adUnitBean)
                                //这里为广告已经缓存好了，保证流畅播放，再次返回成功
                                if (it.isActive){
                                    it.resume(AdResult.Success(adBean = adUnitBean, adObject = mInterstitialFullAd, msg = "GroMore 插屏广告加载成功"))
                                }
                            }
                        })

                    }else{
                        it.resume(AdResult.Fail(adUnitBean, msg = "GroMore加载插屏广告context 类型需要为activity"))
                    }

            }
        }
    }
}